@@ -5,8 +5,9 @@
  *  Copyright (C) 2012  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,9 +20,6 @@
  *
  */
 
-#ifndef __CLIENT_TECHNOLOGY_H
-#define __CLIENT_TECHNOLOGY_H
-
 #include <dbus/dbus.h>
 
 struct tech_data {
@@ -40,5 +38,3 @@ int set_technology(DBusConnection *connection, DBusMessage *message, char *key,
 						char *tech, dbus_bool_t value);
 int scan_technology(DBusConnection *connection, DBusMessage *message,
 						char *tech);
-
-#endif
