@@ -90,10 +90,6 @@ struct connman_network {
 		char *pin_wps;
 	} wifi;
 
-	struct {
-		char *nsp_name;
-		int nsp_name_len;
-	} wimax;
 };
 
 static const char *type2string(enum connman_network_type type)
@@ -106,8 +102,6 @@ static const char *type2string(enum connman_network_type type)
 		return "ethernet";
 	case CONNMAN_NETWORK_TYPE_WIFI:
 		return "wifi";
-	case CONNMAN_NETWORK_TYPE_WIMAX:
-		return "wimax";
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
 		return "bluetooth";
@@ -128,638 +122,6 @@ static gboolean match_driver(struct connman_network *network,
 	return FALSE;
 }
 
-static int network_probe(struct connman_network *network)
-{
-	GSList *list;
-	struct connman_network_driver *driver = NULL;
-
-	DBG("network %p name %s", network, network->name);
-
-	if (network->driver != NULL)
-		return -EALREADY;
-
-	for (list = driver_list; list; list = list->next) {
-		driver = list->data;
-
-		if (match_driver(network, driver) == FALSE)
-			continue;
-
-		DBG("driver %p name %s", driver, driver->name);
-
-		if (driver->probe(network) == 0)
-			break;
-
-		driver = NULL;
-	}
-
-	if (driver == NULL)
-		return -ENODEV;
-
-	if (network->group == NULL)
-		return -EINVAL;
-
-	switch (network->type) {
-	case CONNMAN_NETWORK_TYPE_UNKNOWN:
-	case CONNMAN_NETWORK_TYPE_VENDOR:
-		return 0;
-	case CONNMAN_NETWORK_TYPE_ETHERNET:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-	case CONNMAN_NETWORK_TYPE_CELLULAR:
-	case CONNMAN_NETWORK_TYPE_WIFI:
-	case CONNMAN_NETWORK_TYPE_WIMAX:
-		network->driver = driver;
-		if (__connman_service_create_from_network(network) == NULL) {
-			network->driver = NULL;
-			return -EINVAL;
-		}
-	}
-
-	return 0;
-}
-
-static void network_remove(struct connman_network *network)
-{
-	DBG("network %p name %s", network, network->name);
-
-	if (network->driver == NULL)
-		return;
-
-	connman_network_set_connected(network, FALSE);
-
-	switch (network->type) {
-	case CONNMAN_NETWORK_TYPE_UNKNOWN:
-	case CONNMAN_NETWORK_TYPE_VENDOR:
-		break;
-	case CONNMAN_NETWORK_TYPE_ETHERNET:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-	case CONNMAN_NETWORK_TYPE_CELLULAR:
-	case CONNMAN_NETWORK_TYPE_WIFI:
-	case CONNMAN_NETWORK_TYPE_WIMAX:
-		if (network->group != NULL) {
-			__connman_service_remove_from_network(network);
-
-			g_free(network->group);
-			network->group = NULL;
-		}
-		break;
-	}
-
-	if (network->driver->remove)
-		network->driver->remove(network);
-
-	network->driver = NULL;
-}
-
-static void network_change(struct connman_network *network)
-{
-	DBG("network %p name %s", network, network->name);
-
-	if (network->connected == FALSE)
-		return;
-
-	connman_device_set_disconnected(network->device, TRUE);
-
-	if (network->driver && network->driver->disconnect) {
-		network->driver->disconnect(network);
-		return;
-	}
-
-	network->connected = FALSE;
-}
-
-static void probe_driver(struct connman_network_driver *driver)
-{
-	GSList *list;
-
-	DBG("driver %p name %s", driver, driver->name);
-
-	for (list = network_list; list != NULL; list = list->next) {
-		struct connman_network *network = list->data;
-
-		if (network->driver != NULL)
-			continue;
-
-		if (driver->type != network->type)
-			continue;
-
-		if (driver->probe(network) < 0)
-			continue;
-
-		network->driver = driver;
-	}
-}
-
-static void remove_driver(struct connman_network_driver *driver)
-{
-	GSList *list;
-
-	DBG("driver %p name %s", driver, driver->name);
-
-	for (list = network_list; list != NULL; list = list->next) {
-		struct connman_network *network = list->data;
-
-		if (network->driver == driver)
-			network_remove(network);
-	}
-}
-
-static gint compare_priority(gconstpointer a, gconstpointer b)
-{
-	const struct connman_network_driver *driver1 = a;
-	const struct connman_network_driver *driver2 = b;
-
-	return driver2->priority - driver1->priority;
-}
-
-/**
- * connman_network_driver_register:
- * @driver: network driver definition
- *
- * Register a new network driver
- *
- * Returns: %0 on success
- */
-int connman_network_driver_register(struct connman_network_driver *driver)
-{
-	GSList *list;
-
-	DBG("driver %p name %s", driver, driver->name);
-
-	for (list = driver_list; list; list = list->next) {
-		struct connman_network_driver *tmp = list->data;
-
-		if (tmp->type == driver->type)
-			return -EALREADY;
-
-	}
-
-	driver_list = g_slist_insert_sorted(driver_list, driver,
-							compare_priority);
-
-	probe_driver(driver);
-
-	return 0;
-}
-
-/**
- * connman_network_driver_unregister:
- * @driver: network driver definition
- *
- * Remove a previously registered network driver
- */
-void connman_network_driver_unregister(struct connman_network_driver *driver)
-{
-	DBG("driver %p name %s", driver, driver->name);
-
-	driver_list = g_slist_remove(driver_list, driver);
-
-	remove_driver(driver);
-}
-
-static void network_destruct(struct connman_network *network)
-{
-	DBG("network %p name %s", network, network->name);
-
-	g_free(network->wifi.ssid);
-	g_free(network->wifi.mode);
-	g_free(network->wifi.security);
-	g_free(network->wifi.passphrase);
-	g_free(network->wifi.agent_passphrase);
-	g_free(network->wifi.eap);
-	g_free(network->wifi.identity);
-	g_free(network->wifi.agent_identity);
-	g_free(network->wifi.ca_cert_path);
-	g_free(network->wifi.client_cert_path);
-	g_free(network->wifi.private_key_path);
-	g_free(network->wifi.private_key_passphrase);
-	g_free(network->wifi.phase2_auth);
-	g_free(network->wifi.pin_wps);
-
-	g_free(network->path);
-	g_free(network->group);
-	g_free(network->node);
-	g_free(network->name);
-	g_free(network->identifier);
-
-	network->device = NULL;
-
-	g_free(network);
-}
-
-/**
- * connman_network_create:
- * @identifier: network identifier (for example an unqiue name)
- *
- * Allocate a new network and assign the #identifier to it.
- *
- * Returns: a newly-allocated #connman_network structure
- */
-struct connman_network *connman_network_create(const char *identifier,
-						enum connman_network_type type)
-{
-	struct connman_network *network;
-	char *ident;
-
-	DBG("identifier %s type %d", identifier, type);
-
-	network = g_try_new0(struct connman_network, 1);
-	if (network == NULL)
-		return NULL;
-
-	DBG("network %p", network);
-
-	network->refcount = 1;
-
-	ident = g_strdup(identifier);
-
-	if (ident == NULL) {
-		g_free(network);
-		return NULL;
-	}
-
-	network->type       = type;
-	network->identifier = ident;
-
-	network_list = g_slist_prepend(network_list, network);
-
-	return network;
-}
-
-/**
- * connman_network_ref:
- * @network: network structure
- *
- * Increase reference counter of  network
- */
-struct connman_network *
-connman_network_ref_debug(struct connman_network *network,
-			const char *file, int line, const char *caller)
-{
-	DBG("%p name %s ref %d by %s:%d:%s()", network, network->name,
-		network->refcount + 1, file, line, caller);
-
-	__sync_fetch_and_add(&network->refcount, 1);
-
-	return network;
-}
-
-/**
- * connman_network_unref:
- * @network: network structure
- *
- * Decrease reference counter of network
- */
-void connman_network_unref_debug(struct connman_network *network,
-				const char *file, int line, const char *caller)
-{
-	DBG("%p name %s ref %d by %s:%d:%s()", network, network->name,
-		network->refcount - 1, file, line, caller);
-
-	if (__sync_fetch_and_sub(&network->refcount, 1) != 1)
-		return;
-
-	network_list = g_slist_remove(network_list, network);
-
-	network_destruct(network);
-}
-
-const char *__connman_network_get_type(struct connman_network *network)
-{
-	return type2string(network->type);
-}
-
-/**
- * connman_network_get_type:
- * @network: network structure
- *
- * Get type of network
- */
-enum connman_network_type connman_network_get_type(struct connman_network *network)
-{
-	return network->type;
-}
-
-/**
- * connman_network_get_identifier:
- * @network: network structure
- *
- * Get identifier of network
- */
-const char *connman_network_get_identifier(struct connman_network *network)
-{
-	return network->identifier;
-}
-
-/**
- * connman_network_set_index:
- * @network: network structure
- * @index: index number
- *
- * Set index number of network
- */
-void connman_network_set_index(struct connman_network *network, int index)
-{
-	struct connman_service *service;
-	struct connman_ipconfig *ipconfig;
-
-	service = connman_service_lookup_from_network(network);
-	if (service == NULL)
-		goto done;
-
-	ipconfig = __connman_service_get_ip4config(service);
-	if (ipconfig == NULL)
-		goto done;
-
-	/* If index changed, the index of ipconfig must be reset. */
-	__connman_ipconfig_set_index(ipconfig, index);
-
-	DBG("index %d service %p ip4config %p", network->index,
-		service, ipconfig);
-done:
-	network->index = index;
-}
-
-/**
- * connman_network_get_index:
- * @network: network structure
- *
- * Get index number of network
- */
-int connman_network_get_index(struct connman_network *network)
-{
-	return network->index;
-}
-
-/**
- * connman_network_set_group:
- * @network: network structure
- * @group: group name
- *
- * Set group name for automatic clustering
- */
-void connman_network_set_group(struct connman_network *network,
-							const char *group)
-{
-	switch (network->type) {
-	case CONNMAN_NETWORK_TYPE_UNKNOWN:
-	case CONNMAN_NETWORK_TYPE_VENDOR:
-		return;
-	case CONNMAN_NETWORK_TYPE_ETHERNET:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-	case CONNMAN_NETWORK_TYPE_CELLULAR:
-	case CONNMAN_NETWORK_TYPE_WIFI:
-	case CONNMAN_NETWORK_TYPE_WIMAX:
-		break;
-	}
-
-	if (g_strcmp0(network->group, group) == 0) {
-		if (group != NULL)
-			__connman_service_update_from_network(network);
-		return;
-	}
-
-	if (network->group != NULL) {
-		__connman_service_remove_from_network(network);
-
-		g_free(network->group);
-	}
-
-	network->group = g_strdup(group);
-
-	if (network->group != NULL)
-		network_probe(network);
-}
-
-/**
- * connman_network_get_group:
- * @network: network structure
- *
- * Get group name for automatic clustering
- */
-const char *connman_network_get_group(struct connman_network *network)
-{
-	return network->group;
-}
-
-const char *__connman_network_get_ident(struct connman_network *network)
-{
-	if (network->device == NULL)
-		return NULL;
-
-	return connman_device_get_ident(network->device);
-}
-
-connman_bool_t __connman_network_get_weakness(struct connman_network *network)
-{
-	switch (network->type) {
-	case CONNMAN_NETWORK_TYPE_UNKNOWN:
-	case CONNMAN_NETWORK_TYPE_VENDOR:
-	case CONNMAN_NETWORK_TYPE_ETHERNET:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
-	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-	case CONNMAN_NETWORK_TYPE_CELLULAR:
-	case CONNMAN_NETWORK_TYPE_WIMAX:
-		break;
-	case CONNMAN_NETWORK_TYPE_WIFI:
-		if (g_strcmp0(network->wifi.mode, "adhoc") == 0)
-			return TRUE;
-		if (network->strength > 0 && network->strength < 20)
-			return TRUE;
-		break;
-	}
-
-	return FALSE;
-}
-
-connman_bool_t connman_network_get_connecting(struct connman_network *network)
-{
-	return network->connecting;
-}
-
-/**
- * connman_network_set_available:
- * @network: network structure
- * @available: availability state
- *
- * Change availability state of network (in range)
- */
-int connman_network_set_available(struct connman_network *network,
-						connman_bool_t available)
-{
-	DBG("network %p available %d", network, available);
-
-	if (network->available == available)
-		return -EALREADY;
-
-	network->available = available;
-
-	return 0;
-}
-
-/**
- * connman_network_get_available:
- * @network: network structure
- *
- * Get network available setting
- */
-connman_bool_t connman_network_get_available(struct connman_network *network)
-{
-	return network->available;
-}
-
-/**
- * connman_network_set_associating:
- * @network: network structure
- * @associating: associating state
- *
- * Change associating state of network
- */
-int connman_network_set_associating(struct connman_network *network,
-						connman_bool_t associating)
-{
-	DBG("network %p associating %d", network, associating);
-
-	if (network->associating == associating)
-		return -EALREADY;
-
-	network->associating = associating;
-
-	if (associating == TRUE) {
-		struct connman_service *service;
-
-		service = connman_service_lookup_from_network(network);
-		__connman_service_ipconfig_indicate_state(service,
-					CONNMAN_SERVICE_STATE_ASSOCIATION,
-					CONNMAN_IPCONFIG_TYPE_IPV4);
-		__connman_service_ipconfig_indicate_state(service,
-					CONNMAN_SERVICE_STATE_ASSOCIATION,
-					CONNMAN_IPCONFIG_TYPE_IPV6);
-	}
-
-	return 0;
-}
-
-static void set_associate_error(struct connman_network *network)
-{
-	struct connman_service *service;
-
-	service = connman_service_lookup_from_network(network);
-
-	__connman_service_indicate_error(service,
-					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
-}
-
-static void set_configure_error(struct connman_network *network)
-{
-	struct connman_service *service;
-
-	service = connman_service_lookup_from_network(network);
-
-	__connman_service_indicate_error(service,
-					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
-}
-
-static void set_invalid_key_error(struct connman_network *network)
-{
-	struct connman_service *service;
-
-	service = connman_service_lookup_from_network(network);
-
-	__connman_service_indicate_error(service,
-					CONNMAN_SERVICE_ERROR_INVALID_KEY);
-}
-
-static void set_connect_error(struct connman_network *network)
-{
-	struct connman_service *service;
-
-	service = connman_service_lookup_from_network(network);
-
-	__connman_service_indicate_error(service,
-					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
-}
-
-void connman_network_set_ipv4_method(struct connman_network *network,
-					enum connman_ipconfig_method method)
-{
-	struct connman_service *service;
-	struct connman_ipconfig *ipconfig;
-
-	service = connman_service_lookup_from_network(network);
-	if (service == NULL)
-		return;
-
-	ipconfig = __connman_service_get_ip4config(service);
-	if (ipconfig == NULL)
-		return;
-
-	__connman_ipconfig_set_method(ipconfig, method);
-}
-
-void connman_network_set_ipv6_method(struct connman_network *network,
-					enum connman_ipconfig_method method)
-{
-	struct connman_service *service;
-	struct connman_ipconfig *ipconfig;
-
-	service = connman_service_lookup_from_network(network);
-	if (service == NULL)
-		return;
-
-	ipconfig = __connman_service_get_ip6config(service);
-	if (ipconfig == NULL)
-		return;
-
-	__connman_ipconfig_set_method(ipconfig, method);
-}
-
-void connman_network_set_error(struct connman_network *network,
-					enum connman_network_error error)
-{
-	DBG("nework %p, error %d", network, error);
-
-	network->connecting = FALSE;
-	network->associating = FALSE;
-
-	switch (error) {
-	case CONNMAN_NETWORK_ERROR_UNKNOWN:
-		return;
-	case CONNMAN_NETWORK_ERROR_ASSOCIATE_FAIL:
-		set_associate_error(network);
-		break;
-	case CONNMAN_NETWORK_ERROR_CONFIGURE_FAIL:
-		set_configure_error(network);
-		break;
-	case CONNMAN_NETWORK_ERROR_INVALID_KEY:
-		set_invalid_key_error(network);
-		break;
-	case CONNMAN_NETWORK_ERROR_CONNECT_FAIL:
-		set_connect_error(network);
-		break;
-	}
-
-	network_change(network);
-}
-
-void connman_network_clear_error(struct connman_network *network)
-{
-	struct connman_service *service;
-
-	DBG("network %p", network);
-
-	if (network == NULL)
-		return;
-
-	if (network->connecting == TRUE || network->associating == TRUE)
-		return;
-
-	service = connman_service_lookup_from_network(network);
-	__connman_service_clear_error(service);
-}
-
 static void set_configuration(struct connman_network *network,
 			enum connman_ipconfig_type type)
 {
@@ -1385,6 +747,629 @@ static void set_disconnected(struct connman_network *network)
 	connman_network_set_associating(network, FALSE);
 }
 
+
+
+static int network_probe(struct connman_network *network)
+{
+	GSList *list;
+	struct connman_network_driver *driver = NULL;
+
+	DBG("network %p name %s", network, network->name);
+
+	if (network->driver != NULL)
+		return -EALREADY;
+
+	for (list = driver_list; list; list = list->next) {
+		driver = list->data;
+
+		if (match_driver(network, driver) == FALSE) {
+			driver = NULL;
+			continue;
+		}
+
+		DBG("driver %p name %s", driver, driver->name);
+
+		if (driver->probe(network) == 0)
+			break;
+
+		driver = NULL;
+	}
+
+	if (driver == NULL)
+		return -ENODEV;
+
+	if (network->group == NULL)
+		return -EINVAL;
+
+	switch (network->type) {
+	case CONNMAN_NETWORK_TYPE_UNKNOWN:
+	case CONNMAN_NETWORK_TYPE_VENDOR:
+		return 0;
+	case CONNMAN_NETWORK_TYPE_ETHERNET:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
+	case CONNMAN_NETWORK_TYPE_CELLULAR:
+	case CONNMAN_NETWORK_TYPE_WIFI:
+		network->driver = driver;
+		if (__connman_service_create_from_network(network) == NULL) {
+			network->driver = NULL;
+			return -EINVAL;
+		}
+	}
+
+	return 0;
+}
+
+static void network_remove(struct connman_network *network)
+{
+	DBG("network %p name %s", network, network->name);
+
+	if (network->driver == NULL)
+		return;
+
+	if (network->connected == TRUE)
+		set_disconnected(network);
+
+	switch (network->type) {
+	case CONNMAN_NETWORK_TYPE_UNKNOWN:
+	case CONNMAN_NETWORK_TYPE_VENDOR:
+		break;
+	case CONNMAN_NETWORK_TYPE_ETHERNET:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
+	case CONNMAN_NETWORK_TYPE_CELLULAR:
+	case CONNMAN_NETWORK_TYPE_WIFI:
+		if (network->group != NULL) {
+			__connman_service_remove_from_network(network);
+
+			g_free(network->group);
+			network->group = NULL;
+		}
+		break;
+	}
+
+	if (network->driver->remove)
+		network->driver->remove(network);
+
+	network->driver = NULL;
+}
+
+static void network_change(struct connman_network *network)
+{
+	DBG("network %p name %s", network, network->name);
+
+	if (network->connected == FALSE)
+		return;
+
+	connman_device_set_disconnected(network->device, TRUE);
+
+	if (network->driver && network->driver->disconnect) {
+		network->driver->disconnect(network);
+		return;
+	}
+
+	network->connected = FALSE;
+}
+
+static void probe_driver(struct connman_network_driver *driver)
+{
+	GSList *list;
+
+	DBG("driver %p name %s", driver, driver->name);
+
+	for (list = network_list; list != NULL; list = list->next) {
+		struct connman_network *network = list->data;
+
+		if (network->driver != NULL)
+			continue;
+
+		if (driver->type != network->type)
+			continue;
+
+		if (driver->probe(network) < 0)
+			continue;
+
+		network->driver = driver;
+	}
+}
+
+static void remove_driver(struct connman_network_driver *driver)
+{
+	GSList *list;
+
+	DBG("driver %p name %s", driver, driver->name);
+
+	for (list = network_list; list != NULL; list = list->next) {
+		struct connman_network *network = list->data;
+
+		if (network->driver == driver)
+			network_remove(network);
+	}
+}
+
+static gint compare_priority(gconstpointer a, gconstpointer b)
+{
+	const struct connman_network_driver *driver1 = a;
+	const struct connman_network_driver *driver2 = b;
+
+	return driver2->priority - driver1->priority;
+}
+
+/**
+ * connman_network_driver_register:
+ * @driver: network driver definition
+ *
+ * Register a new network driver
+ *
+ * Returns: %0 on success
+ */
+int connman_network_driver_register(struct connman_network_driver *driver)
+{
+	DBG("driver %p name %s", driver, driver->name);
+
+	driver_list = g_slist_insert_sorted(driver_list, driver,
+							compare_priority);
+
+	probe_driver(driver);
+
+	return 0;
+}
+
+/**
+ * connman_network_driver_unregister:
+ * @driver: network driver definition
+ *
+ * Remove a previously registered network driver
+ */
+void connman_network_driver_unregister(struct connman_network_driver *driver)
+{
+	DBG("driver %p name %s", driver, driver->name);
+
+	driver_list = g_slist_remove(driver_list, driver);
+
+	remove_driver(driver);
+}
+
+static void network_destruct(struct connman_network *network)
+{
+	DBG("network %p name %s", network, network->name);
+
+	g_free(network->wifi.ssid);
+	g_free(network->wifi.mode);
+	g_free(network->wifi.security);
+	g_free(network->wifi.passphrase);
+	g_free(network->wifi.agent_passphrase);
+	g_free(network->wifi.eap);
+	g_free(network->wifi.identity);
+	g_free(network->wifi.agent_identity);
+	g_free(network->wifi.ca_cert_path);
+	g_free(network->wifi.client_cert_path);
+	g_free(network->wifi.private_key_path);
+	g_free(network->wifi.private_key_passphrase);
+	g_free(network->wifi.phase2_auth);
+	g_free(network->wifi.pin_wps);
+
+	g_free(network->path);
+	g_free(network->group);
+	g_free(network->node);
+	g_free(network->name);
+	g_free(network->identifier);
+
+	network->device = NULL;
+
+	g_free(network);
+}
+
+/**
+ * connman_network_create:
+ * @identifier: network identifier (for example an unqiue name)
+ *
+ * Allocate a new network and assign the #identifier to it.
+ *
+ * Returns: a newly-allocated #connman_network structure
+ */
+struct connman_network *connman_network_create(const char *identifier,
+						enum connman_network_type type)
+{
+	struct connman_network *network;
+	char *ident;
+
+	DBG("identifier %s type %d", identifier, type);
+
+	network = g_try_new0(struct connman_network, 1);
+	if (network == NULL)
+		return NULL;
+
+	DBG("network %p", network);
+
+	network->refcount = 1;
+
+	ident = g_strdup(identifier);
+
+	if (ident == NULL) {
+		g_free(network);
+		return NULL;
+	}
+
+	network->type       = type;
+	network->identifier = ident;
+
+	network_list = g_slist_prepend(network_list, network);
+
+	return network;
+}
+
+/**
+ * connman_network_ref:
+ * @network: network structure
+ *
+ * Increase reference counter of  network
+ */
+struct connman_network *
+connman_network_ref_debug(struct connman_network *network,
+			const char *file, int line, const char *caller)
+{
+	DBG("%p name %s ref %d by %s:%d:%s()", network, network->name,
+		network->refcount + 1, file, line, caller);
+
+	__sync_fetch_and_add(&network->refcount, 1);
+
+	return network;
+}
+
+/**
+ * connman_network_unref:
+ * @network: network structure
+ *
+ * Decrease reference counter of network
+ */
+void connman_network_unref_debug(struct connman_network *network,
+				const char *file, int line, const char *caller)
+{
+	DBG("%p name %s ref %d by %s:%d:%s()", network, network->name,
+		network->refcount - 1, file, line, caller);
+
+	if (__sync_fetch_and_sub(&network->refcount, 1) != 1)
+		return;
+
+	network_list = g_slist_remove(network_list, network);
+
+	network_destruct(network);
+}
+
+const char *__connman_network_get_type(struct connman_network *network)
+{
+	return type2string(network->type);
+}
+
+/**
+ * connman_network_get_type:
+ * @network: network structure
+ *
+ * Get type of network
+ */
+enum connman_network_type connman_network_get_type(struct connman_network *network)
+{
+	return network->type;
+}
+
+/**
+ * connman_network_get_identifier:
+ * @network: network structure
+ *
+ * Get identifier of network
+ */
+const char *connman_network_get_identifier(struct connman_network *network)
+{
+	return network->identifier;
+}
+
+/**
+ * connman_network_set_index:
+ * @network: network structure
+ * @index: index number
+ *
+ * Set index number of network
+ */
+void connman_network_set_index(struct connman_network *network, int index)
+{
+	struct connman_service *service;
+	struct connman_ipconfig *ipconfig;
+
+	service = connman_service_lookup_from_network(network);
+	if (service == NULL)
+		goto done;
+
+	ipconfig = __connman_service_get_ip4config(service);
+	if (ipconfig == NULL)
+		goto done;
+
+	/* If index changed, the index of ipconfig must be reset. */
+	__connman_ipconfig_set_index(ipconfig, index);
+
+	DBG("index %d service %p ip4config %p", network->index,
+		service, ipconfig);
+done:
+	network->index = index;
+}
+
+/**
+ * connman_network_get_index:
+ * @network: network structure
+ *
+ * Get index number of network
+ */
+int connman_network_get_index(struct connman_network *network)
+{
+	return network->index;
+}
+
+/**
+ * connman_network_set_group:
+ * @network: network structure
+ * @group: group name
+ *
+ * Set group name for automatic clustering
+ */
+void connman_network_set_group(struct connman_network *network,
+							const char *group)
+{
+	switch (network->type) {
+	case CONNMAN_NETWORK_TYPE_UNKNOWN:
+	case CONNMAN_NETWORK_TYPE_VENDOR:
+		return;
+	case CONNMAN_NETWORK_TYPE_ETHERNET:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
+	case CONNMAN_NETWORK_TYPE_CELLULAR:
+	case CONNMAN_NETWORK_TYPE_WIFI:
+		break;
+	}
+
+	if (g_strcmp0(network->group, group) == 0) {
+		if (group != NULL)
+			__connman_service_update_from_network(network);
+		return;
+	}
+
+	if (network->group != NULL) {
+		__connman_service_remove_from_network(network);
+
+		g_free(network->group);
+	}
+
+	network->group = g_strdup(group);
+
+	if (network->group != NULL)
+		network_probe(network);
+}
+
+/**
+ * connman_network_get_group:
+ * @network: network structure
+ *
+ * Get group name for automatic clustering
+ */
+const char *connman_network_get_group(struct connman_network *network)
+{
+	return network->group;
+}
+
+const char *__connman_network_get_ident(struct connman_network *network)
+{
+	if (network->device == NULL)
+		return NULL;
+
+	return connman_device_get_ident(network->device);
+}
+
+connman_bool_t __connman_network_get_weakness(struct connman_network *network)
+{
+	switch (network->type) {
+	case CONNMAN_NETWORK_TYPE_UNKNOWN:
+	case CONNMAN_NETWORK_TYPE_VENDOR:
+	case CONNMAN_NETWORK_TYPE_ETHERNET:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
+	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
+	case CONNMAN_NETWORK_TYPE_CELLULAR:
+		break;
+	case CONNMAN_NETWORK_TYPE_WIFI:
+		if (g_strcmp0(network->wifi.mode, "adhoc") == 0)
+			return TRUE;
+		if (network->strength > 0 && network->strength < 20)
+			return TRUE;
+		break;
+	}
+
+	return FALSE;
+}
+
+connman_bool_t connman_network_get_connecting(struct connman_network *network)
+{
+	return network->connecting;
+}
+
+/**
+ * connman_network_set_available:
+ * @network: network structure
+ * @available: availability state
+ *
+ * Change availability state of network (in range)
+ */
+int connman_network_set_available(struct connman_network *network,
+						connman_bool_t available)
+{
+	DBG("network %p available %d", network, available);
+
+	if (network->available == available)
+		return -EALREADY;
+
+	network->available = available;
+
+	return 0;
+}
+
+/**
+ * connman_network_get_available:
+ * @network: network structure
+ *
+ * Get network available setting
+ */
+connman_bool_t connman_network_get_available(struct connman_network *network)
+{
+	return network->available;
+}
+
+/**
+ * connman_network_set_associating:
+ * @network: network structure
+ * @associating: associating state
+ *
+ * Change associating state of network
+ */
+int connman_network_set_associating(struct connman_network *network,
+						connman_bool_t associating)
+{
+	DBG("network %p associating %d", network, associating);
+
+	if (network->associating == associating)
+		return -EALREADY;
+
+	network->associating = associating;
+
+	if (associating == TRUE) {
+		struct connman_service *service;
+
+		service = connman_service_lookup_from_network(network);
+		__connman_service_ipconfig_indicate_state(service,
+					CONNMAN_SERVICE_STATE_ASSOCIATION,
+					CONNMAN_IPCONFIG_TYPE_IPV4);
+		__connman_service_ipconfig_indicate_state(service,
+					CONNMAN_SERVICE_STATE_ASSOCIATION,
+					CONNMAN_IPCONFIG_TYPE_IPV6);
+	}
+
+	return 0;
+}
+
+static void set_associate_error(struct connman_network *network)
+{
+	struct connman_service *service;
+
+	service = connman_service_lookup_from_network(network);
+
+	__connman_service_indicate_error(service,
+					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
+}
+
+static void set_configure_error(struct connman_network *network)
+{
+	struct connman_service *service;
+
+	service = connman_service_lookup_from_network(network);
+
+	__connman_service_indicate_error(service,
+					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
+}
+
+static void set_invalid_key_error(struct connman_network *network)
+{
+	struct connman_service *service;
+
+	service = connman_service_lookup_from_network(network);
+
+	__connman_service_indicate_error(service,
+					CONNMAN_SERVICE_ERROR_INVALID_KEY);
+}
+
+static void set_connect_error(struct connman_network *network)
+{
+	struct connman_service *service;
+
+	service = connman_service_lookup_from_network(network);
+
+	__connman_service_indicate_error(service,
+					CONNMAN_SERVICE_ERROR_CONNECT_FAILED);
+}
+
+void connman_network_set_ipv4_method(struct connman_network *network,
+					enum connman_ipconfig_method method)
+{
+	struct connman_service *service;
+	struct connman_ipconfig *ipconfig;
+
+	service = connman_service_lookup_from_network(network);
+	if (service == NULL)
+		return;
+
+	ipconfig = __connman_service_get_ip4config(service);
+	if (ipconfig == NULL)
+		return;
+
+	__connman_ipconfig_set_method(ipconfig, method);
+}
+
+void connman_network_set_ipv6_method(struct connman_network *network,
+					enum connman_ipconfig_method method)
+{
+	struct connman_service *service;
+	struct connman_ipconfig *ipconfig;
+
+	service = connman_service_lookup_from_network(network);
+	if (service == NULL)
+		return;
+
+	ipconfig = __connman_service_get_ip6config(service);
+	if (ipconfig == NULL)
+		return;
+
+	__connman_ipconfig_set_method(ipconfig, method);
+}
+
+void connman_network_set_error(struct connman_network *network,
+					enum connman_network_error error)
+{
+	DBG("network %p error %d", network, error);
+
+	network->connecting = FALSE;
+	network->associating = FALSE;
+
+	switch (error) {
+	case CONNMAN_NETWORK_ERROR_UNKNOWN:
+		return;
+	case CONNMAN_NETWORK_ERROR_ASSOCIATE_FAIL:
+		set_associate_error(network);
+		break;
+	case CONNMAN_NETWORK_ERROR_CONFIGURE_FAIL:
+		set_configure_error(network);
+		break;
+	case CONNMAN_NETWORK_ERROR_INVALID_KEY:
+		set_invalid_key_error(network);
+		break;
+	case CONNMAN_NETWORK_ERROR_CONNECT_FAIL:
+		set_connect_error(network);
+		break;
+	}
+
+	network_change(network);
+}
+
+void connman_network_clear_error(struct connman_network *network)
+{
+	struct connman_service *service;
+
+	DBG("network %p", network);
+
+	if (network == NULL)
+		return;
+
+	if (network->connecting == TRUE || network->associating == TRUE)
+		return;
+
+	service = connman_service_lookup_from_network(network);
+	__connman_service_clear_error(service);
+}
+
 /**
  * connman_network_set_connected:
  * @network: network structure
@@ -2100,7 +2085,6 @@ void connman_network_update(struct connman_network *network)
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
 	case CONNMAN_NETWORK_TYPE_CELLULAR:
 	case CONNMAN_NETWORK_TYPE_WIFI:
-	case CONNMAN_NETWORK_TYPE_WIMAX:
 		break;
 	}
 
